@@ -52,12 +52,12 @@ def has_all_permissions(request, check_list=[]):
     """
     Checks if request.user the given list of permission on the current request.site
     """
-    if not check_list:
-        return True
-        
-    if request.user.is_superuser: 
+    if not check_list or request.user.is_superuser:
         return True
 
+    if not request.user.is_authenticated:
+        return False
+
     has_permission = False
     
     user_groups_field = get_user_model()._meta.get_field('groups')
